/***************************************************************************//**
 *   @file   ADXRS453.h
 *   @brief  Header file of ADXRS453 Driver.
 *   @author Bancisor Mihai
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 408
*******************************************************************************/
#ifndef __ADXRS453_H__
#define __ADXRS453_H__

/******************************************************************************/
/* ADXRS453                                                                   */
/******************************************************************************/
#define ADXRS453_STARTUP_DELAY	0.05 /* sec */

/* The MSB for the spi commands */
#define ADXRS453_SENSOR_DATA	0x20
#define ADXRS453_WRITE_DATA		0x40
#define ADXRS453_READ_DATA		0x80
/* Memory register map */
#define ADXRS453_RATE1			0x00	/* Rate Registers */
#define ADXRS453_TEMP1			0x02	/* Temperature Registers */
#define ADXRS453_LOCST1			0x04	/* Low CST Memory Registers */
#define ADXRS453_HICST1			0x06	/* High CST Memory Registers */
#define ADXRS453_QUAD1			0x08	/* Quad Memory Registers */
#define ADXRS453_FAULT1			0x0A	/* Fault Registers */
#define ADXRS453_PID1			0x0C	/* Part ID Register 1 */
#define ADXRS453_SNH			0x0E	/* Serial Number Registers, 4 bytes */
#define ADXRS453_SNL			0x10

/* Check bits */
#define ADXRS453_P				0x01	/* Parity bit */
#define ADXRS453_CHK			0x02	
#define ADXRS453_CST			0x04
#define ADXRS453_PWR			0x08
#define ADXRS453_POR			0x10
#define ADXRS453_NVM			0x20
#define ADXRS453_Q				0x40
#define ADXRS453_PLL			0x80
#define ADXRS453_UV				0x100
#define ADXRS453_OV				0x200
#define ADXRS453_AMP			0x400
#define ADXRS453_FAIL			0x800

#define ADXRS453_WRERR_MASK		(0x7 << 29)
#define ADXRS453_GET_ST(a)		((a >> 26) & 0x3)	/* Status bits*/

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
/* Initializes the ADXRS453 and checks if the device is present. */
unsigned char 	ParityBit(unsigned long data);
/* Reads data from ADXRS453. */
unsigned long 	ADXRS456_Data(void);
/* Reads register from ADXRS453. */
unsigned short	ADXRS456_GetRegisterValue(unsigned char regAddress);
/* Writes register to ADXRS453. */
void ADXRS456_SetRegisterValue(unsigned char regAddress, unsigned short regData);
/* Reads temperature from ADXRS453 and converts it to degrees Celsius. */
unsigned char ADXRS456_GetTemperature(void);

#endif	// ADXRS453_H_
